@@ -1,18 +1,17 @@
-from cast_common.restAPI import RestCall
-from cast_common.logger import INFO
-from requests import codes
-from pandas import DataFrame,json_normalize,concat
+from restAPI import RestCall
+from requests import codes, post
+from pandas import DataFrame
+from pandas import json_normalize
+from pandas import concat
+from logging import DEBUG, INFO, ERROR, warning
 
-__author__ = "Nevin Kaplan"
-__email__ = "n.kaplan@castsoftware.com"
-__copyright__ = "Copyright 2022, CAST Software"
 
 class HLRestCall(RestCall):
     """
     Class to handle HL REST API calls.
     """
     def __init__(self, hl_base_url, hl_user, hl_pswd, hl_instance, timer_on=False,log_level=INFO):
-        super().__init__(hl_base_url, hl_user, hl_pswd, timer_on,log_level,accept_json=False)
+        super().__init__(hl_base_url, hl_user, hl_pswd, timer_on,log_level)
 
         self._hl_instance = hl_instance
         self._hl_data_retrieved = False
@@ -63,7 +62,8 @@ class HLRestCall(RestCall):
             for id in json:
                 if id['name'].lower()==app_name.lower():
                     return id['id']
-            raise KeyError (f'Highlight application not found: {app_name}')
+            #raise KeyError (f'Highlight application not found: {app_name}')
+            return None
 
     def get_cloud_data(self,app_id):
         url = f'domains/{self._hl_instance}/applications/{app_id}'
@@ -126,6 +126,15 @@ class HLRestCall(RestCall):
                 lic=lic[['component','version','languages','release','origin','lastVersion','license','compliance']] 
 
         return lic,cves,len(third_party)
+    
+    def create_an_app(self, url, instance_id, app_name):
+        url = f'{url}/domains/{instance_id}/applications/'
+        payload =[{"name": app_name,"domains": [{"id": instance_id}]}]
+
+        resp = post(url, auth=self._auth, json=payload)        
+        #print(resp.status_code)
+
+        return resp.status_code
 
 def load_df_element(src,dst,name):
     if not (src.get(name) is None):
